@@ -2,7 +2,8 @@ from pathlib import Path
 from typing import Optional
 
 import click
-from beepy import beep
+
+# from beepy import beep
 from click import ClickException
 
 
@@ -147,12 +148,12 @@ def build(
     else:
         report.print()
     if report.has_error():
-        beep(3)  # sad error
+        # beep(3)  # sad error
         ex = ClickException("Something is wrong.")
         ex.exit_code = 1
         raise ex
-    else:
-        beep(5)
+    # else:
+    # beep(5)
 
 
 @supermark.command(help="Show info about a project and installation.")
